# =============================================================================================
# Minimax Estimation of the Volume of a Set under the Rolling Ball Condition
# =============================================================================================

# ----------------------------------------------------------------------
# volest       Estimation of the volume of a set
# ----------------------------------------------------------------------

# Usage
# volest(x, alpha, wf, ...)

# Arguments: 
# x  			n x 2 sample
# alpha           value of alpha for ahull computation
# wf              which observations in the first subsample
# ...             arguments to be passed to methods

# Details:
# Requires alphahull package (version 2.1)

# Value
# A list with the following components:
# vhat            estimation of volume
# phat            fraction of the second subsample that fall outside the alpha convex hull of the first subsample
# areafah         area of the alpha convex hull of the first subsample

volest <-
function (x, alpha, wf, ...) 
{
    n <- dim(x)[1]
    wf <- unique(wf)
    fx <- x[wf, ]    # First subsample
    sx <- x[-wf, ]   # Second subsample
    fah <- ahull(fx, alpha = alpha)   # Alpha convex hull of the first subsample
    areafah <- areaahull(fah, ...)    # Area of fah
    if (is.na(areafah)) {
        warning("Cannot compute correct alphahull: returning NA")
        vhat <- NA
        phatc <- NA
    }
    else {
        infah <- inahull(fah, sx)
        phatc <- mean(infah)              # Fraction of the second subsample that fall inside the ahull of the first subsample
        vhat <- areafah/max(phatc, 0.5)   # Volume estimation
    }
    return(list(vhat = vhat, phat = 1 - phatc, areafah = areafah))
}

